import "server-only";
import { codeToHtml } from "shiki";
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
export let config = {
	themes: {
		light: "vitesse-light",
		dark: "vitesse-dark"
	},
	selectors: "system"
};
export function updateConfig(newConfig) {
	config = newConfig;
}
let lightSystemSelector = [
	"@media (prefers-color-scheme: light) {",
	".kanapa-dark:not(.kanapa-override) { display: none; }",
	"}"
];
let darkSystemSelector = [
	"@media (prefers-color-scheme: dark) {",
	".kanapa-light:not(.kanapa-override) { display: none; }",
	"}"
];
let systemStyleString = [...lightSystemSelector, ...darkSystemSelector].join("").replace(/\s+/g, "");
export async function Code({ lang, children, code, theme, className }) {
	if (!code && !children) {
		throw new Error("One of `code` or `children` props are required!");
	}
	let codeToHighlight = code || children;
	if (theme) {
		let highlighted = await codeToHtml(codeToHighlight, {
			lang,
			theme
		});
		return _jsx("div", {
			className: `kanapa-${theme} kanapa-override kanapa-wrap${className ? ` ${className}` : ""}`,
			dangerouslySetInnerHTML: { __html: highlighted }
		});
	}
	let pendingHighlights = [];
	for (let [themeType, theme] of Object.entries(config.themes)) {
		pendingHighlights.push({
			themeType,
			highlighted: codeToHtml(codeToHighlight, {
				lang,
				theme
			})
		});
	}
	let styleString;
	if (config.selectors === "system") {
		styleString = systemStyleString;
	} else if (typeof config.selectors.light === "string" && typeof config.selectors.dark === "string") {
		styleString = [`:where(${config.selectors.light}) .kanapa-dark:not(.kanapa-override){display:none;}`, `:where(${config.selectors.dark}) .kanapa-light:not(.kanapa-override){display:none;}`].join("");
	} else {
		throw new Error("Invalid `config.selectors` configuration, must be either 'system' or an object with both light and dark key-value pairs");
	}
	return _jsxs(_Fragment, { children: [_jsx("style", {
		href: "kanapa-styles",
		precedence: "high",
		children: styleString
	}), pendingHighlights.map(async ({ themeType, highlighted }) => _jsx("div", {
		className: `kanapa-${themeType} kanapa-wrap${className ? ` ${className}` : ""}`,
		dangerouslySetInnerHTML: { __html: await highlighted }
	}, themeType))] });
}
export async function MDXCode(props) {
	let code = props?.children?.props?.children;
	let lang = "text";
	let classes = props?.children?.props?.className.split(" ");
	for (let cls of classes) {
		if (cls.startsWith("language-")) {
			lang = cls.split("language-")[1];
			break;
		}
	}
	return _jsx(Code, {
		className: props.className,
		lang,
		children: code
	});
}
